
|PythonBadge|

Visions
=======

..

    *And these visions of data types, they kept us up past the dawn.*

..

`Visions` provides an extensible suite of tools to support common data analysis operations including

* type inference on unknown data
* casting data types
* automated data summarization

Documentation
-------------

Full documentation can be found `here <https://dylan-profiler.github.io/visions/>`_.

Installation
------------

You can install `visions` via pip:

.. code-block:: console

    pip install visions

Alternatives and more details can be found in the `documentation <https://dylan-profiler.github.io/visions/visions/getting_started/installation.html>`_.


Acknowledgements
----------------

This package is part of the `dylan-profiler <https://github.com/dylan-profiler>`_ project.
The package is core component of `pandas-profiling <https://github.com/pandas-profiling/pandas-profiling>`_.
More information can be found `here <https://dylan-profiler.github.io/visions/visions/about.html>`__.

.. |PythonBadge| image:: https://img.shields.io/pypi/pyversions/visions